Config class

Config entity

Constructors

Config({required double percentage, required List<String> excludeSuffixes, required bool includeUntestedFiles, required List<RegExp> excludeFiles, required List<RegExp> excludeContents, required bool log, String? packageName, ArgResults? command, String? lcovGen, String? excludeContentsPath})

Properties

command → ArgResults?
final
excludeContents ↔ List<RegExp>
file content patterns
getter/setter pair
excludeContentsPath → String?
excludeContentsPath
final
excludeFiles ↔ List<RegExp>
file name patterns
getter/setter pair
excludeSuffixes → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
includeUntestedFiles → bool
final
lcovGen → String?
lcovGen
final
log → bool
final
packageName → String?
final
percentage → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited