ConfigModel class

Config model

Constructors

ConfigModel({required double percentage, required List<String> excludeSuffixes, required bool includeUntestedFiles, required List<RegExp> excludeFiles, required List<RegExp> excludeContents, required bool log, String? packageName, ArgResults? command, String? lcovGen, String? excludeContentsPath})

Properties

command → ArgResults?
Command
final
excludeContents → List<RegExp>
content/code patterns
final
excludeContentsPath → String?
excludeContentsPath
final
excludeFiles → List<RegExp>
file name patterns
final
excludeSuffixes → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
includeUntestedFiles → bool
final
lcovGen → String?
lcov generator
final
log → bool
log
final
packageName → String?
package name
final
percentage → double
percentage
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited