FileMatcherUtil class

Constructors

FileMatcherUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasPattern({required String value, required List<RegExp> patterns}) → bool
Check if has pattern
hasPatterns({required List<String> values, required List<RegExp> patterns}) → bool
Check if has patterns
hasSuffix({required String file, required List<String> excludeSuffixes}) → bool
Check if has suffix
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited