FileSystemUtil class

Constructors

FileSystemUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAsLinesSync(String path) → List<String>
toString() → String
A string representation of this object.
inherited
writeToFile(String content, String path) → Future<File>

Operators

operator ==(Object other) → bool
The equality operator.
inherited