Logger class

Constructors

Logger()

Properties

coverageParam → String
final
hashCode → int
The hash code for this object.
no setterinherited
minCoverageParam → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successParam → String
final

Methods

log(Lcov lcov) → void
log test coverage values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited